dhg
=========

Load Structure
----------------

.. autofunction:: dhg.load_structure

Low-Order Structures
-----------------------

Base Class
+++++++++++++++++

.. autoclass:: dhg.BaseGraph
    :members:

.. _dhg_graph_class:

Graph
+++++++++++++++++

.. autoclass:: dhg.Graph
    :show-inheritance:
    :members:

.. _dhg_digraph_class:

Directed Graph
+++++++++++++++++

.. autoclass:: dhg.DiGraph
    :show-inheritance:
    :members:

.. _dhg_bigraph_class:

Bipartite Graph
+++++++++++++++++

.. autoclass:: dhg.BiGraph
    :show-inheritance:
    :members:

High-Order Structures
----------------------

Base Class
+++++++++++++++++

.. autoclass:: dhg.BaseHypergraph
    :members:

.. _dhg_hypergraph_class:

Hypergraph
+++++++++++++++++

.. autoclass:: dhg.Hypergraph
    :show-inheritance:
    :members:
